@@ -14,11 +14,12 @@
 """Write and run Hadoop Streaming jobs on Amazon Elastic MapReduce or your own Hadoop cluster.
 """
 __author__ = 'David Marin <dave@yelp.com>'
-__credits__ = ['Adam Derewicki <derwiki@yelp.com>',
+__credits__ = ['James Brown <jbrown@yelp.com>',
+               'Adam Derewicki <derwiki@yelp.com>',
                'Brett Hoerner <brett@bretthoerner.com>',
                'Matt Jones <mattj@yelp.com>',
                'Julian Krause <juliank@yelp.com>',
                'Jimmy Retzlaff <jretz@yelp.com>',
                'Ned Rockson <ned@tellapart.com>',
                'Paul Wais <pwais@yelp.com>']
-__version__ = '0.2.2'
+__version__ = '0.2.3'
