@@ -1,4 +1,4 @@
-# Copyright 2009-2010 Yelp
+# Copyright 2009-2011 Yelp and Contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -52,7 +52,7 @@ from mrjob.util import cmd_line
 
 log = logging.getLogger('mrjob.emr')
 
-S3_URI_RE = re.compile(r'^s3://([A-Za-z0-9-]+)/(.*)$')
+S3_URI_RE = re.compile(r'^s3://([A-Za-z0-9-\.]+)/(.*)$')
 JOB_TRACKER_RE = re.compile('(\d{1,3}\.\d{2})%')
 
 # if EMR throttles us, how long to wait (in seconds) before trying again?
@@ -714,7 +714,7 @@ class EMRJobRunner(MRJobRunner):
         emr_conn = self.make_emr_conn()
         log.debug('Calling run_jobflow(%r, %r, %s)' % (
             self._job_name, self._opts['s3_log_uri'],
-            ', '.join('%r=%r' % (k, v) for k, v in args.iteritems())))
+            ', '.join('%s=%r' % (k, v) for k, v in args.iteritems())))
         emr_job_flow_id = emr_conn.run_jobflow(
             self._job_name, self._opts['s3_log_uri'], **args)
 
@@ -979,9 +979,10 @@ class EMRJobRunner(MRJobRunner):
 
         assert self._script # shouldn't call _script_args() if no script
 
-        args = ['python', self._script['name']]
+        args = [self._opts['python_bin'], self._script['name']]
         if self._wrapper_script:
-            args = ['python', self._wrapper_script['name']] + args
+            args = [self._opts['python_bin'],
+                    self._wrapper_script['name']] + args
 
         return args
 
@@ -1091,7 +1092,17 @@ class EMRJobRunner(MRJobRunner):
 
         relevant_logs.sort(reverse=True)
 
+        tasks_seen = set()
+
         for sort_key, info, s3_log_file_uri in relevant_logs:
+            # Issue #31: Don't bother with errors from tasks that
+            # later succeeded
+            task_info = (info['step_num'], info['node_type'],
+                         info['node_num'], info['stream'])
+            if task_info in tasks_seen:
+                continue
+            tasks_seen.add(task_info)
+
             log_path = self._download_log_file(s3_log_file_uri, s3_conn)
             if not log_path:
                 continue
