@@ -1,4 +1,4 @@
-# Copyright 2009-2010 Yelp
+# Copyright 2009-2011 Yelp and Contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -270,6 +270,11 @@ class HadoopJobRunner(MRJobRunner):
 
             streaming_args = [self._opts['hadoop_bin'], 'jar', self._opts['hadoop_streaming_jar']]
 
+            # Add extra hadoop args first as hadoop args could be a hadoop
+            # specific argument (e.g. -libjar) which must come before job
+            # specific args.
+            streaming_args.extend(self._opts['hadoop_extra_args'])
+
             # add environment variables
             for key, value in sorted(self._cmdenv.iteritems()):
                 streaming_args.append('-cmdenv')
@@ -290,9 +295,6 @@ class HadoopJobRunner(MRJobRunner):
             for key, value in sorted(self._opts['jobconf'].iteritems()):
                 streaming_args.extend(['-jobconf', '%s=%s' % (key, value)])
 
-            # add extra hadoop args
-            streaming_args.extend(self._opts['hadoop_extra_args'])
-
             # set up mapper and reducer
             streaming_args.append('-mapper')
             streaming_args.append(cmd_line(self._mapper_args(step_num)))
@@ -340,9 +342,11 @@ class HadoopJobRunner(MRJobRunner):
     def _script_args(self):
         """How to invoke the script inside Hadoop"""
         assert self._script # shouldn't be able to run if no script
-        args = ['python', self._script['name']]
+
+        args = [self._opts['python_bin'], self._script['name']]
         if self._wrapper_script:
-            args = ['python', self._wrapper_script['name']] + args
+            args = [self._opts['python_bin'],
+                    self._wrapper_script['name']] + args
 
         return args
 
