@@ -1,4 +1,4 @@
-# Copyright 2009-2010 Yelp
+# Copyright 2009-2011 Yelp and Contributors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -122,6 +122,8 @@ class MRJobRunner(object):
         :param owner: who is running this job. Used solely to set the job name. By default, we use :py:func:`getpass.getuser`, or ``no_user`` if it fails.
         :type python_archives: list of str
         :param python_archives: same as upload_archives, except they get added to the job's :envvar:`PYTHONPATH`
+        :type python_bin: str
+        :param python_bin: Name/path of alternate python binary for mappers/reducers (e.g. for use with :py:mod:`virtualenv`). Defaults to ``'python'``.
         :type setup_cmds: list
         :param setup_cmds: a list of commands to run before each mapper/reducer step (e.g. ``['cd my-src-tree; make', 'mkdir -p /tmp/foo']``). You can specify commands as strings, which will be run through the shell, or lists of args, which will be invoked directly. We'll use file locking to ensure that multiple mappers/reducers running on the same node won't run *setup_cmds* simultaneously (it's safe to run ``make``).
         :type setup_scripts: list of str
@@ -248,8 +250,8 @@ class MRJobRunner(object):
         """A list of which keyword args we can pass to __init__()"""
         return ['base_tmp_dir', 'bootstrap_mrjob', 'cleanup', 'cmdenv',
                 'hadoop_extra_args', 'jobconf', 'label', 'owner',
-                'python_archives', 'setup_cmds', 'setup_scripts',
-                'upload_archives', 'upload_files']
+                'python_archives', 'python_bin', 'setup_cmds',
+                'setup_scripts', 'upload_archives', 'upload_files']
 
     @classmethod
     def _default_opts(cls):
@@ -265,6 +267,7 @@ class MRJobRunner(object):
             'bootstrap_mrjob': True,
             'cleanup': CLEANUP_DEFAULT,
             'owner': owner,
+            'python_bin': 'python',
         }
 
     @classmethod
@@ -278,6 +281,7 @@ class MRJobRunner(object):
             'hadoop_extra_args': combine_lists,
             'jobconf': combine_dicts,
             'python_archives': combine_path_lists,
+            'python_bin': combine_paths,
             'setup_cmds': combine_lists,
             'setup_scripts': combine_path_lists,
             'upload_archives': combine_path_lists,
@@ -661,6 +665,8 @@ class MRJobRunner(object):
             if not self._script:
                 self._steps = []
             else:
+                # don't use self._opts['python_bin'] because that
+                # refers to the python binary to use inside Hadoop
                 python_bin = sys.executable or 'python'
                 args = ([python_bin, self._script['path'], '--steps'] +
                         self._mr_job_extra_args(local=True))
